@@ -65,10 +65,11 @@ for a in sys.argv[1:]:
 uargs = tmp
 
 try:
-	opts, args = getopt.gnu_getopt(uargs, "hvlc:ei:u:s:n:t:p:a:A:z:",\
+	opts, args = getopt.gnu_getopt(uargs, "hvlc:ei:u:s:n:p:a:A:z:",\
 	["help", "version", "list", "check=","examples","install=",\
-	"uninstall=","size=","number=","text=","purge=","all=","all-recurse=","zip="])
+	"uninstall=","size=","number=","purge=","all=","all-recurse=","zip="])
 except getopt.GetoptError, err:
+	print _("Your arguments amuse me :) Please read the help.")
 	print str(err) # will print something like "option -a not recognized"
 	raise SystemExit
 
@@ -126,13 +127,6 @@ for o, a in opts:
 			raise SystemExit			
 		options.numinpage = n
 
-	elif o in ("-t", "--text"):
-		## The quotes gets stripped out, so I can't tell the
-		## end of the text param and the start of other params
-		## therefore I stick to the 'report and restart' idea.
-		options.text = a
-		fpsys.config.text = a
-
 	elif o in ("-a", "--all", "-A","--all-recurse"):
 		## var a is whatever comes after the -a flag.
 		options.all = a # save to flag a test later (line 310)
@@ -154,7 +148,6 @@ for o, a in opts:
 
 	else:
 		## We should not reach here at all.
-		print "Your arguments amuse me :) Please read the help."
 		raise SystemExit
 
 ####
@@ -210,7 +203,7 @@ if options.zip:
 		todir="." #always where we run this
 		ipog = fontcontrol.Pog( options.pog )
 		ipog.zip( todir )
-		print _("Zipped as %s.zip in this directory.") % options.pog
+		print _("Zipped as %s.fonts.zip in this directory.") % options.pog
 	else:
 		print _("I can't find a pog named %s") % options.pog
 	raise SystemExit
@@ -229,18 +222,7 @@ if options.numinpage > 1:
 
 ####
 ## Text
-## This one has potential to screw-up badly
-## if the user forgets the quotes.
-## For now, I will exit app.
-if options.text:
-	fpsys.config.text = options.text
-	fpsys.config.Save()		
-	print _("""Your text has been set to "%s"
-Tip: Did you use quotes to surround your text?
-
-Please start FontyPython again to see the result.""") % options.text
-	raise SystemExit
-
+## Removed Oct 2009 : It was useless.
 
 
 ####
