@@ -28,6 +28,7 @@ LSP = linux_safe_path_library.linuxSafePath()
 import pathcontrol
 import strings
 import fontcontrol
+import charmaps
 
 import wx
 
@@ -270,7 +271,7 @@ class FPState:
 		
 state = FPState() #The only instance of the state object -- app-wide
 
-
+		
 ####
 ## Save and Load the conf file
 class Configure:
@@ -281,7 +282,7 @@ class Configure:
 		self.__dontSaveNumInPage = False
 		
 		## PUBLIC vars :  Set some defaults:
-		self.size = (400,600) 
+		self.size = (800,600) 
 		self.pos = (10, 10)
 		self.numinpage = 10
 		self.text = _("Jump the lazy dog fox")
@@ -291,17 +292,21 @@ class Configure:
 		self.max = True
 		self.lastdir = iPC.home()
 		## Added Dec 2007
-		self.leftSash = 128
+		self.leftSash = 200 
 		self.rightSash = 128
 		## Added June 2009
 		self.recurseFolders = False 
 		## Added Sept 2009
 		self.ignore_adjustments = False
 		## Added 3 Oct 2009
-		self.app_char_map = None # A string of an app name.
+		self.app_char_map = "UNSET" # A string of an app name.
 
 		self.__setData()
 		
+		## Oct 2009 -- The Character Map Controller.
+		self.CMC = charmaps.CharMapController(  self.app_char_map_set )
+
+		
 		if os.path.exists(iPC.appConf()):
 			try:
 				pf = open(iPC.appConf(), "rb" ) # Binary for new pickle protocol.
@@ -315,6 +320,7 @@ class Configure:
 			print _("No config file found, creating it with defaults.")
 			self.Save() 
 			
+
 		## Now get them into the instance vars:
 		try:
 			self.size = self.__data['size']
@@ -331,7 +337,11 @@ class Configure:
 			self.recurseFolders = self.__data['recurseFolders']
 			self.ignore_adjustments = self.__data['ignore_adjustments']
 			self.app_char_map = self.__data['app_char_map']
-			
+			## We must also set our instance of the Char Map Controller:
+			##  This can be "UNSET" (default first run) or an appname
+			##  That appname may be valid or not (it may have been uninstalled...)
+			self.CMC.SET_CURRENT_APPNAME(self.app_char_map)
+
 		except KeyError:
 			## The conf file has keys that don't work for this version, chances are it's old.
 			## Let's delete and re-make it.
@@ -342,27 +352,6 @@ class Configure:
 				raise SystemExit
 			self.Save()
 		
-		## Oct 2009 -- The Character Map Viewer external app.
-		## See also: dialogues.py
-		self.GOT_APPS = self.make_apps_list()
-		if self.GOT_APPS is []: self.app_char_map = None
-
-	def make_apps_list( self ):
-		'''Return a list of a choice of installed charmap viewers, or []'''
-		def does_app_exist( program ):
-			for path in os.environ.get('PATH', '').split(':'):
-				if os.path.exists(os.path.join(path, program)) and \
-				   not os.path.isdir(os.path.join(path, program)):
-					#return os.path.join(path, program)
-					return program
-			return None
-		validapps = ['gucharmap','kfontview']
-		apps=[]
-		apps.append( does_app_exist(validapps[0]) )
-		apps.append( does_app_exist(validapps[1]) )
-		got_apps=[str(t) for t in apps if t is not None]
-		if self.app_char_map not in validapps: self.app_char_map = None
-		return got_apps
 
 	def dontSaveNumInPage(self, flag):
 		self.__dontSaveNumInPage = flag
@@ -382,6 +371,13 @@ class Configure:
 								"ignore_adjustments": self.ignore_adjustments,
 								"app_char_map" : self.app_char_map
 								}
+	def app_char_map_set( self, x ):
+		'''
+		A callback from the CharMapController: when the CURRENT_APPNAME is set,
+		this gets called to keep the config version of the appname current.
+		'''
+		self.app_char_map = x
+		
 	def Save(self) :
 		#If we are NOT to save the numinpage, then fetch it from what was there before.
 		if self.__dontSaveNumInPage:
