@@ -173,6 +173,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		self.Bind(wx.EVT_MIDDLE_UP, self.onMiddleClick)	
 		#self.Bind(wx.EVT_LEFT_DCLICK, self.onDClick)
 		self.Bind( wx.EVT_MOTION, self.onHover )
+		self.Bind( wx.EVT_LEAVE_WINDOW, self.onLeave)
 
 		## Redraw event
 		self.Bind(wx.EVT_PAINT,  self.onPaint) 
@@ -199,55 +200,26 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		argstup=(fi.glyphpaf, dest, self.fitem.family[0],fpsys.config.points )
 
 		## Never done threading before. Not really sure if this is kosher...
-		thread = threading.Thread(target=self.run, args=argstup)
-		thread.setDaemon(True)
-		thread.start()
+
+		#~ MICHAEL 4.2011:
+		#~ I tried threading myself, too. But I don't really understand it
+		#~ down to the present day. As I see "Popen" in charmaps.py/Run
+		#~ starts his own thread, so we don`t need to make assurance double sure.
+		#~ By the way, this push gucharmap to work as we want.
+		
+		self.run(*argstup)
+
+		#~ thread = threading.Thread(target=self.run, args=argstup)
+		#~ thread.setDaemon(True)
+		#~ thread.start()
 
 	def run(self, *args):
-		src=args[0]
-		dest=args[1]
-		fam=args[2]
-		sz=args[3]
-
-		if fpsys.config.app_char_map == "gucharmap":
-			makelink=True
-			cmd = ['gucharmap', u'--font=%s, %s' % (fam, sz)]
-		elif fpsys.config.app_char_map == "kfontview":
-			makelink=False # kfontview only needs a url to a font file. It rules.
-			url = src
-			cmd = ['kfontview', u'%s' % url]
-		else:
-			return
-
-		if makelink:
-			## gucharmap requires the font to be installed already, so fake it:
-			fail=False
-			already_installed = False
-			try:
-				os.symlink( src, dest )
-			except OSError, detail:
-				if detail.errno != 17:
-					# Not 17 means the link failed, don't open the charmap
-					fail = True
-				else:
-					# Error 17: file exists.
-					# User may have installed it previously (or something).
-					already_installed = True
-			if fail: return
-
-		proc = subprocess.Popen( cmd, shell=False )
-		## gucharmap: Fonty actually holds still and waits here until gucharmap is closed.
-		## kfontview: Fonty just runs-through. kfontview is a different beast.
-		## Both still work and Fonty stays active. Multiple instances if the viewers can be opened!
-		proc.wait()
-
-		# Remove the fake installed font -- if it's a candidate:
-		if makelink and not already_installed:
-			try:
-				os.unlink( dest )
-			except:
-				# What to do? Start yelling? Nah...
-				pass
+		'''
+		Uses the instance (held in fpsys.config) of the classes in charmaps.py.
+		'''
+		iCM = fpsys.config.CMC.GetInstance()
+		iCM.OpenApp( *args )
+		iCM.Cleanup( )
 
 	def onMiddleClick(self, event):
 		ps.pub( menu_settings, None )
@@ -261,7 +233,7 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 
 		Other fitems like info and FILE_NOT_FOUND don't get buttons.
 		'''
-		if not fpsys.config.app_char_map: return False
+		if not fpsys.config.CMC.APPS_ARE_AVAILABLE: return False
 		if isinstance( self.fitem, fontcontrol.InfoFontItem ): return False
 		if self.fitem.badstyle == "FILE_NOT_FOUND": return False
 		if not self.fitem.family: return False
@@ -286,6 +258,13 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 	def overout_signal( self ):
 		if self.overout.state:
 			self.SetCursor( self.CURSOR )
+
+	def onLeave(self, event):
+		'''
+		Catch the leave event for set the charmap button off,
+		if the pointer goes out on the left edge.
+		'''
+		self.onHover(event)
 			
 	def onClick(self, event) :
 		if self.cmb_overout.state and self.can_have_button():
@@ -332,7 +311,6 @@ class Fitmap(wx.lib.statbmp.GenStaticBitmap):
 		wx.BeginBusyCursor()
 		if not self.fitem.top_left_adjust_completed:
 			W,H = pilimage.size
-			#if  not self.fitem.fx[i] and not self.fitem.fy[i]:
 			fx=fy=0
 			esc = False
 			# Scan ACROSS WIDTH and repeatedly DOWN looking for a pixel.
